@@ -4,10 +4,11 @@ from .remote_exec import remote_exec
 from . import vars
 from .cc_debug import cc_print
 from tempfile import gettempdir
-from os import mkdir
+from os import mkdir, path
+import sys, __main__
 
 # CloudComputing version
-__version__ = "0.2.2"
+__version__ = "0.3.0"
 # Author (GitHub username)
 __author__ = "mp1994"
 
@@ -30,4 +31,9 @@ vars.tempdir = gettempdir() + "/cc_cache/"
 try:
     mkdir(vars.tempdir)
 except FileExistsError:
-    pass
\ No newline at end of file
+    pass
+# Get path of calling script (if any)
+if hasattr(__main__, "get_ipython"):
+    vars.__file__ = None
+else:
+    vars.__file__ = path.abspath(sys.argv[0])
\ No newline at end of file
